/* Creation Date:  11/16/98 11:20:44 */
/* Version:  5.00.0007  */
/* General Topic Area:  All RequisitePro triggers.  */
/* Notes:  These Triggers enforce referential integrity and effect cascading deletes.
                For the error handling to work properly, the messages must exist in the
                sysmessages table. */

Setuser
Go

If Exists(select * from sysusers where uid = user_id('ReqPro'))
	Setuser 'ReqPro'
Go


/**************************************
	Table: RQDISCUSSIONGROUPS
**************************************/

	/* Trigger RQDISCUSSIONGROUPS_ITRIG */
	If exists (select * From sysobjects Where name = 'RQDISCUSSIONGROUPS_ITRIG' and type = 'TR')
		drop trigger RQDISCUSSIONGROUPS_ITRIG
	Go
	Create Trigger RQDISCUSSIONGROUPS_ITRIG On RQDISCUSSIONGROUPS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDISCUSSIONS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDISCUSSIONS, inserted Where (RQDISCUSSIONS.ID = inserted.DISCUSSIONID))
		    Begin
		        Raiserror(778000, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERGROUPS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.GROUPID))
		    Begin
		        Raiserror(778011, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQDISCUSSIONREQUIREMENTS 
**************************************/

	/*  Trigger RQDISCUSSIONREQUIREMENTS_ITRIG */
	If exists (select * From sysobjects Where name = 'RQDISCUSSIONREQUIREMENTS_ITRIG' and type = 'TR')
		drop trigger RQDISCUSSIONREQUIREMENTS_ITRIG
	Go
	Create Trigger RQDISCUSSIONREQUIREMENTS_ITRIG On RQDISCUSSIONREQUIREMENTS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDISCUSSIONS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDISCUSSIONS, inserted Where (RQDISCUSSIONS.ID = inserted.DISCUSSIONID))
		    Begin
		        Raiserror(778000, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.REQUIREMENTID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQDISCUSSIONS 
**************************************/

	/* Trigger RQDISCUSSIONS_DTRIG */
	If exists (select * From sysobjects Where name = 'RQDISCUSSIONS_DTRIG' and type = 'TR')
		drop trigger RQDISCUSSIONS_DTRIG
	Go
	Create Trigger RQDISCUSSIONS_DTRIG On RQDISCUSSIONS For Delete As
		Delete RQDISCUSSIONGROUPS From deleted, RQDISCUSSIONGROUPS Where deleted.ID = RQDISCUSSIONGROUPS.DISCUSSIONID
		delete RQDISCUSSIONREQUIREMENTS from deleted, RQDISCUSSIONREQUIREMENTS where deleted.ID = RQDISCUSSIONREQUIREMENTS.DISCUSSIONID
		delete RQDISCUSSIONSREAD from deleted, RQDISCUSSIONSREAD where deleted.ID = RQDISCUSSIONSREAD.DISCUSSIONID
		delete RQDISCUSSIONUSERS from deleted, RQDISCUSSIONUSERS where deleted.ID = RQDISCUSSIONUSERS.DISCUSSIONID
		delete RQPROJECTDISCUSSIONS from deleted, RQPROJECTDISCUSSIONS where deleted.ID = RQPROJECTDISCUSSIONS.DISCUSSIONID
	go

	/* TRIGGER RQDISCUSSIONS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQDISCUSSIONS_UTRIG' and type = 'TR')
		Drop Trigger RQDISCUSSIONS_UTRIG
	Go
	Create Trigger RQDISCUSSIONS_UTRIG On RQDISCUSSIONS For Update As
		/* Prevent Updates if dependent records in 'RQDISCUSSIONGROUPS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDISCUSSIONGROUPS Where (deleted.ID = RQDISCUSSIONGROUPS.DISCUSSIONID)) > 0
		            Begin
						Raiserror(779000, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQDISCUSSIONREQUIREMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDISCUSSIONREQUIREMENTS Where (deleted.ID = RQDISCUSSIONREQUIREMENTS.DISCUSSIONID)) > 0
		            Begin
						Raiserror(779001, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQDISCUSSIONSREAD' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDISCUSSIONSREAD Where (deleted.ID = RQDISCUSSIONSREAD.DISCUSSIONID)) > 0
		            Begin
						Raiserror(779002, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQDISCUSSIONUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDISCUSSIONUSERS Where (deleted.ID = RQDISCUSSIONUSERS.DISCUSSIONID)) > 0
		            Begin
						Raiserror(779003, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTDISCUSSIONS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTDISCUSSIONS Where (deleted.ID = RQPROJECTDISCUSSIONS.DISCUSSIONID)) > 0
		            Begin
						Raiserror(779009, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQDISCUSSIONSREAD
**************************************/

	/* Trigger RQDISCUSSIONSREAD_ITRIG */
	If exists (select * From sysobjects Where name = 'RQDISCUSSIONSREAD_ITRIG' and type = 'TR')
		drop trigger RQDISCUSSIONSREAD_ITRIG
	Go
	Create Trigger RQDISCUSSIONSREAD_ITRIG On RQDISCUSSIONSREAD For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDISCUSSIONS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDISCUSSIONS, inserted Where (RQDISCUSSIONS.ID = inserted.DISCUSSIONID))
		    Begin
		        Raiserror(778000, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERS, inserted Where (RQUSERS.ID = inserted.USERID))
		    Begin
		        Raiserror(778012, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQDISCUSSIONUSERS
**************************************/

	/* Trigger RQDISCUSSIONUSERS_ITRIG */
	If exists (select * From sysobjects Where name = 'RQDISCUSSIONUSERS_ITRIG' and type = 'TR')
		drop trigger RQDISCUSSIONUSERS_ITRIG
	Go
	Create Trigger RQDISCUSSIONUSERS_ITRIG On RQDISCUSSIONUSERS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDISCUSSIONS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDISCUSSIONS, inserted Where (RQDISCUSSIONS.ID = inserted.DISCUSSIONID))
		    Begin
		        Raiserror(778000, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERS, inserted Where (RQUSERS.ID = inserted.USERID))
		    Begin
		        Raiserror(778012, 16, 1)
		        Rollback Transaction
		    End
	Go

/**************************************
	Table: RQDOCUMENTHISTORY
**************************************/

	/* Trigger RQDOCUMENTHISTORY_ITRIG */
	If Exists (Select* From sysobjects Where name = 'RQDOCUMENTHISTORY_ITRIG' and type = 'TR')
		Drop Trigger RQDOCUMENTHISTORY_ITRIG
	Go
	Create Trigger RQDOCUMENTHISTORY_ITRIG On RQDOCUMENTHISTORY For Insert, Update As
		/* Prevent inserts/updates if no matching key in 'RqDocuments' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDOCUMENTS, inserted Where (RQDOCUMENTS.ID = inserted.ID))
		    Begin
		        Raiserror(778001, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQDOCUMENTS
**************************************/

	/* Trigger RQDOCUMENTS_DTRIG */
	If Exists (Select* From sysobjects Where name = 'RQDOCUMENTS_DTRIG' and type = 'TR')
		Drop Trigger RQDOCUMENTS_DTRIG
	Go
	Create Trigger RQDOCUMENTS_DTRIG On RQDOCUMENTS For Delete As
		Delete RQDOCUMENTHISTORY From deleted, RQDOCUMENTHISTORY Where deleted.ID = RQDOCUMENTHISTORY.ID
		Delete RQPROJECTDOCUMENTS From deleted, RQPROJECTDOCUMENTS Where deleted.ID = RQPROJECTDOCUMENTS.DOCUMENTID
		Delete RQUSERDEFINEDDOCRELVALUES From deleted, RQUSERDEFINEDDOCRELVALUES Where deleted.ID = RQUSERDEFINEDDOCRELVALUES.DOCUMENTID
		Delete RQPACKAGEELEMENTS From deleted, RQPACKAGEELEMENTS Where deleted.ID = RQPACKAGEELEMENTS.DOCUMENTID
	Go

	/* Trigger RQDOCUMENTS_ITRIG */
	If Exists (Select* From sysobjects Where name = 'RQDOCUMENTS_ITRIG' and type = 'TR')
		Drop Trigger RQDOCUMENTS_ITRIG
	Go
	Create Trigger RQDOCUMENTS_ITRIG On RQDOCUMENTS For Insert, Update As
		/* Prevent Updates if dependent records in 'RQDOCUMENTHISTORY' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From inserted, RQDOCUMENTHISTORY Where (inserted.ID = RQDOCUMENTHISTORY.ID)) > 0
		            Begin
				Raiserror(779004, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTDOCUMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From inserted, RQPROJECTDOCUMENTS Where (inserted.ID = RQPROJECTDOCUMENTS.DOCUMENTID)) > 0
		            Begin
				Raiserror(779010, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent inserts/updates if no matching key in 'RQDOCUMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDOCUMENTTYPES, inserted Where (RQDOCUMENTTYPES.ID = inserted.DOCUMENTTYPEID))
		    Begin
		        Raiserror(778002, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Updates if dependent records in RQUSERDEFINEDDOCRELVALUES */
		If Update(ID)
		    Begin
		        If (Select Count(*) From inserted, RQUSERDEFINEDDOCRELVALUES WHERE (inserted.ID = RQUSERDEFINEDDOCRELVALUES.DOCUMENTID)) > 0
		            Begin
				Raiserror(779030, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in RQPACKAGEELEMENTS */
		If Update(ID)
		    Begin
		        If (Select Count(*) From inserted, RQPACKAGEELEMENTS WHERE (inserted.ID = RQPACKAGEELEMENTS.DOCUMENTID)) > 0
		            Begin
						Raiserror(779034, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQDOCUMENTTYPES
**************************************/

	/* Trigger RQDOCUMENTTYPES_DTRIG */
	If Exists (Select* From sysobjects Where name = 'RQDOCUMENTTYPES_DTRIG' and type = 'TR')
		Drop Trigger RQDOCUMENTTYPES_DTRIG
	Go
	Create Trigger RQDOCUMENTTYPES_DTRIG On RQDOCUMENTTYPES For Delete As
		/* Prevent Deletes if dependent records in RqDocuments */
		If (Select Count(*) From deleted, RQDOCUMENTS Where (deleted.ID = RQDOCUMENTS.DOCUMENTTYPEID)) > 0
		    Begin
		        Raiserror(779005, 16, 1)
		        Rollback Transaction
		    End
		Delete RQDOCUMENTTYPEUSERS From deleted, RQDOCUMENTTYPEUSERS Where deleted.ID = RQDOCUMENTTYPEUSERS.DOCUMENTTYPEID
		Delete RQPROJECTDOCUMENTTYPES From deleted, RQPROJECTDOCUMENTTYPES Where deleted.ID = RQPROJECTDOCUMENTTYPES.DOCUMENTTYPEID
	Go

	/* Trigger RQDOCUMENTTYPES_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQDOCUMENTTYPES_UTRIG' and type = 'TR')
		Drop Trigger RQDOCUMENTTYPES_UTRIG
	Go
	Create Trigger RQDOCUMENTTYPES_UTRIG On RQDOCUMENTTYPES For Update As
		/* Prevent Updates if dependent records in 'RQDOCUMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDOCUMENTS Where (deleted.ID = RQDOCUMENTS.DOCUMENTTYPEID)) > 0
		            Begin
				Raiserror(779005, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQDOCUMENTTYPEUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDOCUMENTTYPEUSERS Where (deleted.ID = RQDOCUMENTTYPEUSERS.DOCUMENTTYPEID)) > 0
		            Begin
				Raiserror(779006, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTDOCUMENTTYPES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTDOCUMENTTYPES Where (deleted.ID = RQPROJECTDOCUMENTTYPES.DOCUMENTTYPEID)) > 0
		            Begin
				Raiserror(779011, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go

/**************************************
	Table: RQDOCUMENTTYPEUSERS
**************************************/

	/* Trigger RQDOCUMENTTYPEUSERS_ITRIG */
	If Exists (Select* From sysobjects Where name = 'RQDOCUMENTTYPEUSERS_ITRIG' and type = 'TR')
		Drop Trigger RQDOCUMENTTYPEUSERS_ITRIG
	Go
	Create Trigger RQDOCUMENTTYPEUSERS_ITRIG On RQDOCUMENTTYPEUSERS For Insert, Update As
		/* Prevent inserts/updates if no matching key in 'RqDocumentTypes' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDOCUMENTTYPES, inserted Where (RQDOCUMENTTYPES.ID = inserted.DOCUMENTTYPEID))
		    Begin
		        Raiserror(778002, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent inserts/updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent inserts/updates if no matching key in 'RQUSERGROUPS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.USERGROUPID))
		    Begin
		        Raiserror(778011, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQEXTERNALPROJECTS
**************************************/

	/* Trigger RQEXTERNALPROJECTS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQEXTERNALPROJECTS_DTRIG' and type = 'TR')
		Drop Trigger RQEXTERNALPROJECTS_DTRIG
	Go
	Create Trigger RQEXTERNALPROJECTS_DTRIG On RQEXTERNALPROJECTS For Delete As
		Delete RQPROJECTEXTERNALPROJECTS From deleted, RQPROJECTEXTERNALPROJECTS Where deleted.ID = RQPROJECTEXTERNALPROJECTS.EXTERNALPROJECTID
	Go

	/* Trigger RQEXTERNALPROJECTS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQEXTERNALPROJECTS_UTRIG' and type = 'TR')
		Drop Trigger RQEXTERNALPROJECTS_UTRIG
	Go
	Create Trigger RQEXTERNALPROJECTS_UTRIG On RQEXTERNALPROJECTS For Update As
		/* Prevent Updates if dependent records in 'RQPROJECTEXTERNALPROJECTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTEXTERNALPROJECTS Where (deleted.ID = RQPROJECTEXTERNALPROJECTS.EXTERNALPROJECTID)) > 0
		            Begin
						Raiserror(779012, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQQUERYDEFINITIONS
**************************************/

	/* Trigger RQQUERYDEFINITIONS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQQUERYDEFINITIONS_DTRIG' and type = 'TR')
		Drop Trigger RQQUERYDEFINITIONS_DTRIG
	Go
	Create Trigger RQQUERYDEFINITIONS_DTRIG On RQQUERYDEFINITIONS For Delete As
		Delete RQVIEWS From deleted, RQVIEWS Where deleted.ID = RQVIEWS.QUERYID
	Go

	/* Trigger RQQUERYDEFINITIONS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQQUERYDEFINITIONS_ITRIG' and type = 'TR')
		Drop Trigger RQQUERYDEFINITIONS_ITRIG
	Go
	Create Trigger RQQUERYDEFINITIONS_ITRIG On RQQUERYDEFINITIONS For Insert As
		/* Prevent Inserts if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
	Go


	/* Trigger RQQUERYDEFINITIONS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQQUERYDEFINITIONS_UTRIG' and type = 'TR')
		Drop Trigger RQQUERYDEFINITIONS_UTRIG
	Go
	Create Trigger RQQUERYDEFINITIONS_UTRIG On RQQUERYDEFINITIONS For Update As
		/* Prevent Updates if dependent records in 'RQVIEWS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQVIEWS Where (deleted.ID = RQVIEWS.QUERYID)) > 0
		            Begin
						Raiserror(779029, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if no matching key in 'RQPROJECTS' */
		If Update(PROJECTID)
		    Begin
		        If (Select Count(*) From deleted) != (Select Count(*) From RQPROJECTS, deleted Where (RQPROJECTS.ID = deleted.PROJECTID))
		            Begin
						Raiserror(778004, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQVIEWS
**************************************/

	/* Trigger RQVIEWS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQVIEWS_DTRIG' and type = 'TR')
		Drop Trigger RQVIEWS_DTRIG
	Go
	Create Trigger RQVIEWS_DTRIG On RQVIEWS For Delete As
		Delete RQPACKAGEELEMENTS From deleted, RQPACKAGEELEMENTS Where deleted.ID = RQPACKAGEELEMENTS.VIEWID
	Go

	/* Trigger RQVIEWS_ITRIG    Script Date: 10/9/98 15:13:25 ******/
	If Exists (Select * From sysobjects Where name = 'RQVIEWS_ITRIG' and type = 'TR')
		Drop Trigger RQVIEWS_ITRIG
	Go
	Create Trigger RQVIEWS_ITRIG On RQVIEWS For Insert As
		/* Prevent Inserts if no matching key in 'RQQUERYDEFINITIONS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQQUERYDEFINITIONS, inserted Where (RQQUERYDEFINITIONS.ID = inserted.QUERYID))
		    Begin
		        Raiserror(778005, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
	Go

	/* Trigger RQVIEWS_UTRIG    Script Date: 10/9/98 15:13:25 ******/
	If Exists (Select * From sysobjects Where name = 'RQVIEWS_UTRIG' and type = 'TR')
		Drop Trigger RQVIEWS_UTRIG
	Go
	Create Trigger RQVIEWS_UTRIG On RQVIEWS For Update As
		/* Prevent Updates if no matching key in 'RQQUERYDEFINITIONS' */
		If Update(QUERYID)
		    Begin
		        If (Select Count(*) From deleted) != (Select Count(*) From RQQUERYDEFINITIONS, deleted Where (RQQUERYDEFINITIONS.ID = deleted.QUERYID))
		            Begin
				Raiserror(778005, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if no matching key in 'RQPROJECTS' */
		If Update(PROJECTID)
		    Begin
		        If (Select Count(*) From deleted) != (Select Count(*) From RQPROJECTS, deleted Where (RQPROJECTS.ID = deleted.PROJECTID))
		            Begin
				Raiserror(778004, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPACKAGEELEMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPACKAGEELEMENTS Where (deleted.ID = RQPACKAGEELEMENTS.VIEWID)) > 0
		            Begin
				Raiserror(779034, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQOVERFLOWTEXT
**************************************/

	/* Trigger RQOVERFLOWTEXT_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQOVERFLOWTEXT_ITRIG' and type = 'TR')
		Drop Trigger RQOVERFLOWTEXT_ITRIG
	Go
	Create Trigger RQOVERFLOWTEXT_ITRIG ON RQOVERFLOWTEXT For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.OVERFLOWID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQOVERFLOWVALUES
**************************************/

	/* Trigger RQOVERFLOWVALUES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQOVERFLOWVALUES_ITRIG' and type = 'TR')
		Drop Trigger RQOVERFLOWVALUES_ITRIG
	Go
	Create Trigger RQOVERFLOWVALUES_ITRIG ON RQOVERFLOWVALUES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.OVERFLOWFIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDVALUES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDVALUES, inserted Where (RQUSERDEFINEDFIELDVALUES.REQUIREMENTID = inserted.OVERFLOWREQUIREMENTID AND RQUSERDEFINEDFIELDVALUES.FIELDID = inserted.OVERFLOWFIELDID))
		    Begin
		        Raiserror(778009, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPACKAGEELEMENTS
**************************************/

	/* Trigger RQPACKAGEELEMENTS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPACKAGEELEMENTS_ITRIG' and type = 'TR')
		Drop Trigger RQPACKAGEELEMENTS_ITRIG
	Go

	Create Trigger RQPACKAGEELEMENTS_ITRIG ON RQPACKAGEELEMENTS For Insert, Update As

		/* Prevent Inserts/Updates if no matching key in 'RQPACKAGES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPACKAGES, inserted Where (RQPACKAGES.ID = inserted.PACKAGEID))
		    Begin
		        Raiserror(778014, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) from inserted where inserted.REQUIREMENTID Is Not Null) !=
                   (Select Count(*) from RQREQUIREMENTS, inserted where RQREQUIREMENTS.ID = inserted.REQUIREMENTID)
		    Begin
			Raiserror(778006,16,1)
			Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQDOCUMENTS' */
		If (Select Count(*) from inserted where inserted.DOCUMENTID Is Not Null) !=
                   (Select Count(*) from RQDOCUMENTS, inserted where RQDOCUMENTS.ID = inserted.DOCUMENTID)
		    Begin
			Raiserror(778001,16,1)
			Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQVIEWS' */
		If (Select Count(*) from inserted where inserted.VIEWID Is Not Null) !=
                   (Select Count(*) from RQVIEWS, inserted where RQVIEWS.ID = inserted.VIEWID)
		    Begin
			Raiserror(778013,16,1)
			Rollback Transaction
		    End
	Go

/**************************************
	Table: RQPACKAGES
**************************************/

	/* Trigger RQPACKAGES_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQPACKAGES_DTRIG' and type = 'TR')
		Drop Trigger RQPACKAGES_DTRIG
	Go

	Create Trigger RQPACKAGES_DTRIG On RQPACKAGES For Delete As

		/* Prevent Deletes if dependent records in 'RQPACKAGEELEMENTS' */
		If (Select Count(*) From deleted, RQPACKAGEELEMENTS Where (deleted.ID = RQPACKAGEELEMENTS.PACKAGEID)) > 0
			Begin
				Raiserror(779034, 16, 1)
				Rollback Transaction
			End
		/* Prevent Deletes if dependent records in 'RQPACKAGES' */
		If (Select Count(*) From deleted, RQPACKAGES Where (deleted.ID = RQPACKAGES.PARENTID)) > 0
			Begin
				Raiserror(779033, 16, 1)
				Rollback Transaction
			End
	Go


	/* Trigger RQPACKAGES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPACKAGES_ITRIG' and type = 'TR')
		Drop Trigger RQPACKAGES_ITRIG
	Go

	Create Trigger RQPACKAGES_ITRIG On RQPACKAGES For Insert As

		/* Prevent Inserts if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
			Begin
				Raiserror(778004, 16, 1)
				Rollback Transaction
			End
		/* Prevent Inserts if no matching key in 'RQPACKAGES' */
		If (Select Count(*) From inserted Where PARENTID Is Not Null) != (Select Count(*) From RQPACKAGES, inserted Where (RQPACKAGES.ID = inserted.PARENTID))
			Begin
				Raiserror(778014, 16, 1)
				Rollback Transaction
			End
	
	Go

	/* Trigger RQPACKAGES_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQPACKAGES_UTRIG' and type = 'TR')
		Drop Trigger RQPACKAGES_UTRIG
	Go

	Create Trigger RQPACKAGES_UTRIG On RQPACKAGES For Update As
	
		/* Prevent Updates if no matching key in 'RQPROJECTS' */
		If Update(PROJECTID)
			Begin
				If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
					Begin
						Raiserror(778004, 16, 1)
						Rollback Transaction
					End
			End
		/* Prevent Updates if dependent records in 'RQPACKAGEELEMENTS' */
		If Update(ID)
			Begin
				If (Select Count(*) From deleted, RQPACKAGEELEMENTS Where (deleted.ID = RQPACKAGEELEMENTS.PACKAGEID)) > 0
					Begin
						Raiserror(779034, 16, 1)
						Rollback Transaction
					End
			End
		/* Prevent Updates if no matching key in 'RQPACKAGES' */
		If Update(PARENTID)
			Begin
				If (Select Count(*) From inserted, RQPACKAGES Where inserted.PARENTID = RQPACKAGES.ID) != 
	               (Select Count(*) From inserted Where inserted.PARENTID Is Not Null)
					Begin
						Raiserror(778014, 16, 1)
						Rollback Transaction
					End
			End
	Go


/**************************************
	Table: RQPROJECTDISCUSSIONS
**************************************/

	/* Trigger RQPROJECTDISCUSSIONS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTDISCUSSIONS_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTDISCUSSIONS_ITRIG
	Go
	Create Trigger RQPROJECTDISCUSSIONS_ITRIG On RQPROJECTDISCUSSIONS For Insert, Update As
	/* Prevent Inserts/Updates if no matching key in 'RQDISCUSSIONS' */
	If (Select Count(*) From inserted) != (Select Count(*) From RQDISCUSSIONS, inserted Where (RQDISCUSSIONS.ID = inserted.DISCUSSIONID))
	    Begin
	        Raiserror(778000, 16, 1)
	        Rollback Transaction
	    End
	/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
	If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
	    Begin
	        Raiserror(778004, 16, 1)
	        Rollback Transaction
	    End

	Go


/**************************************
	Table: RQPROJECTDOCUMENTS
**************************************/
	
	/* Trigger RQPROJECTDOCUMENTS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTDOCUMENTS_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTDOCUMENTS_ITRIG
	Go
	Create Trigger RQPROJECTDOCUMENTS_ITRIG On RQPROJECTDOCUMENTS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDOCUMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDOCUMENTS, inserted Where (RQDOCUMENTS.ID = inserted.DOCUMENTID))
		    Begin
		        Raiserror(778001, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) !=
		   (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPROJECTDOCUMENTTYPES
**************************************/

	/* Trigger RQPROJECTDOCUMENTTYPES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTDOCUMENTTYPES_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTDOCUMENTTYPES_ITRIG
	Go
	Create Trigger RQPROJECTDOCUMENTTYPES_ITRIG On RQPROJECTDOCUMENTTYPES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDOCUMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDOCUMENTTYPES, inserted Where (RQDOCUMENTTYPES.ID = inserted.DOCUMENTTYPEID))
		    Begin
		        Raiserror(778002, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPROJECTEXTERNALPROJECTS
**************************************/

	/* Trigger RQPROJECTEXTERNALPROJ_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTEXTERNALPROJ_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTEXTERNALPROJ_ITRIG
	Go
	Create Trigger RQPROJECTEXTERNALPROJ_ITRIG On RQPROJECTEXTERNALPROJECTS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQEXTERNALPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQEXTERNALPROJECTS, inserted Where (RQEXTERNALPROJECTS.ID = inserted.EXTERNALPROJECTID))
		    Begin
		        Raiserror(778003, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPROJECTHISTORY
**************************************/

	/* Trigger RQPROJECTHISTORY_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTHISTORY_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTHISTORY_ITRIG
	Go
	Create Trigger RQPROJECTHISTORY_ITRIG On RQPROJECTHISTORY For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.ID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPROJECTREQUIREMENTS
**************************************/

	/* Trigger RQPROJECTREQUIREMENTS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTREQUIREMENTS_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTREQUIREMENTS_ITRIG
	Go
	Create Trigger RQPROJECTREQUIREMENTS_ITRIG On RQPROJECTREQUIREMENTS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.REQUIREMENTID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPROJECTREQUIREMENTTYPES
**************************************/

	/* Trigger RQPROJECTREQTYPES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTREQTYPES_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTREQTYPES_ITRIG
	Go
	Create Trigger RQPROJECTREQTYPES_ITRIG On RQPROJECTREQUIREMENTTYPES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTTYPES, inserted Where (RQREQUIREMENTTYPES.ID = inserted.REQUIREMENTTYPEID))
		    Begin
		        Raiserror(778007, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQPROJECTS
**************************************/

	/* Trigger RQPROJECTS_DTRIG */
	If Exists (SELECT * FROM sysobjects WHERE name = 'RQPROJECTS_DTRIG' AND type = 'TR')
		Drop Trigger RQPROJECTS_DTRIG
	Go
	Create Trigger RQPROJECTS_DTRIG On RQPROJECTS For Delete As
		Delete RQDOCUMENTTYPEUSERS From deleted, RQDOCUMENTTYPEUSERS Where deleted.ID = RQDOCUMENTTYPEUSERS.PROJECTID
		Delete RQPROJECTDISCUSSIONS From deleted, RQPROJECTDISCUSSIONS Where deleted.ID = RQPROJECTDISCUSSIONS.PROJECTID
		Delete RQPROJECTDOCUMENTS From deleted, RQPROJECTDOCUMENTS Where deleted.ID = RQPROJECTDOCUMENTS.PROJECTID
		Delete RQPROJECTDOCUMENTTYPES From deleted, RQPROJECTDOCUMENTTYPES Where deleted.ID = RQPROJECTDOCUMENTTYPES.PROJECTID
		Delete RQPROJECTEXTERNALPROJECTS From deleted, RQPROJECTEXTERNALPROJECTS Where deleted.ID = RQPROJECTEXTERNALPROJECTS.PROJECTID
		Delete RQPROJECTHISTORY From deleted, RQPROJECTHISTORY Where deleted.ID = RQPROJECTHISTORY.ID
		Delete RQPROJECTREQUIREMENTS From deleted, RQPROJECTREQUIREMENTS Where deleted.ID = RQPROJECTREQUIREMENTS.PROJECTID
		Delete RQPROJECTREQUIREMENTTYPES From deleted, RQPROJECTREQUIREMENTTYPES Where deleted.ID = RQPROJECTREQUIREMENTTYPES.PROJECTID
		Delete RQPROJECTUSERS From deleted, RQPROJECTUSERS Where deleted.ID = RQPROJECTUSERS.PROJECTID
		Delete RQREQUIREMENTTYPEUSERS From deleted, RQREQUIREMENTTYPEUSERS Where deleted.ID = RQREQUIREMENTTYPEUSERS.PROJECTID
		Delete RQUSERDEFINEDFIELDUSERS From deleted, RQUSERDEFINEDFIELDUSERS Where deleted.ID = RQUSERDEFINEDFIELDUSERS.PROJECTID
		Delete RQUSERDEFINEDLISTITEMUSERS From deleted, RQUSERDEFINEDLISTITEMUSERS Where deleted.ID = RQUSERDEFINEDLISTITEMUSERS.PROJECTID
		Delete RQVIEWS From deleted, RQVIEWS Where deleted.ID = RQVIEWS.PROJECTID
		Delete RQQUERYDEFINITIONS From deleted, RQQUERYDEFINITIONS Where deleted.ID = RQQUERYDEFINITIONS.PROJECTID
		Delete RQPACKAGES From deleted, RQPACKAGES Where deleted.ID = RQPACKAGES.PROJECTID
	Go

	/* Trigger RQPROJECTS_DTRIG_BLOCK */
	If Exists (SELECT * FROM sysobjects WHERE name = 'RQPROJECTS_DTRIG_BLOCK' AND type = 'TR')
		Drop Trigger RQPROJECTS_DTRIG_BLOCK
	Go
	Create Trigger RQPROJECTS_DTRIG_BLOCK On RQPROJECTS For Delete As
		Raiserror(779032,16,1)
		Rollback Transaction
	Go

	/* Enable RQPROJECTS_DTRIG_BLOCK, Disable RQPROJECTS_DTRIG */
	Alter Table RQPROJECTS Disable Trigger RQPROJECTS_DTRIG
	Go
	Alter Table RQPROJECTS Enable Trigger RQPROJECTS_DTRIG_BLOCK
	Go 

	/* Trigger RQPROJECTS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTS_UTRIG' and type = 'TR')
		Drop Trigger RQPROJECTS_UTRIG
	Go
	Create Trigger RQPROJECTS_UTRIG On RQPROJECTS For Update As
		/* Prevent Updates if dependent records in 'RQDOCUMENTTYPEUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDOCUMENTTYPEUSERS Where (deleted.ID = RQDOCUMENTTYPEUSERS.PROJECTID)) > 0
		            Begin
						Raiserror(779006, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTDISCUSSIONS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTDISCUSSIONS Where (deleted.ID = RQPROJECTDISCUSSIONS.PROJECTID)) > 0
		            Begin
						Raiserror(779009, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTDOCUMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTDOCUMENTS Where (deleted.ID = RQPROJECTDOCUMENTS.PROJECTID)) > 0
		            Begin
						Raiserror(779010, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTDOCUMENTTYPES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTDOCUMENTTYPES Where (deleted.ID = RQPROJECTDOCUMENTTYPES.PROJECTID)) > 0
		            Begin
						Raiserror(779011, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTEXTERNALPROJECTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTEXTERNALPROJECTS Where (deleted.ID = RQPROJECTEXTERNALPROJECTS.PROJECTID)) > 0
		            Begin
						Raiserror(779012, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTHISTORY' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTHISTORY Where (deleted.ID = RQPROJECTHISTORY.ID)) > 0
		            Begin
						Raiserror(779013, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTREQUIREMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTREQUIREMENTS Where (deleted.ID = RQPROJECTREQUIREMENTS.PROJECTID)) > 0
		            Begin
						Raiserror(779014, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTREQUIREMENTTYPES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTREQUIREMENTTYPES Where (deleted.ID = RQPROJECTREQUIREMENTTYPES.PROJECTID)) > 0
		            Begin
						Raiserror(779015, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTUSERS Where (deleted.ID = RQPROJECTUSERS.PROJECTID)) > 0
		            Begin
						Raiserror(779016, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTTYPEUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTTYPEUSERS Where (deleted.ID = RQREQUIREMENTTYPEUSERS.PROJECTID)) > 0
		            Begin
						Raiserror(779022, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDFIELDUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDFIELDUSERS Where (deleted.ID = RQUSERDEFINEDFIELDUSERS.PROJECTID)) > 0
		            Begin
						Raiserror(779023, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTITEMUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTITEMUSERS Where (deleted.ID = RQUSERDEFINEDLISTITEMUSERS.PROJECTID)) > 0
		            Begin
						Raiserror(779026, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQVIEWS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQVIEWS Where (deleted.ID = RQVIEWS.PROJECTID)) > 0
		            Begin
						Raiserror(779029, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPACKAGES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPACKAGES Where (deleted.ID = RQPACKAGES.PROJECTID)) > 0
		            Begin
						Raiserror(779033, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQPROJECTUSERS
**************************************/

	/* Trigger RQPROJECTUSERS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQPROJECTUSERS_ITRIG' and type = 'TR')
		Drop Trigger RQPROJECTUSERS_ITRIG
	Go
	Create Trigger RQPROJECTUSERS_ITRIG On RQPROJECTUSERS For Insert, Update As
		 /* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		 /* Prevent Inserts/Updates if no matching key in 'RQUSERGROUPS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.USERGROUPID))
		    Begin
		        Raiserror(778011, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQREQUIREMENTHISTORY
**************************************/

	/* Trigger RQREQUIREMENTHISTORY_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTHISTORY_ITRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTHISTORY_ITRIG
	Go
	Create Trigger RQREQUIREMENTHISTORY_ITRIG On RQREQUIREMENTHISTORY For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.ID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQREQUIREMENTS
**************************************/

	/* Trigger RQREQUIREMENTS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTS_DTRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTS_DTRIG
	Go
	Create Trigger RQREQUIREMENTS_DTRIG On RQREQUIREMENTS For Delete As
		Delete RQDISCUSSIONREQUIREMENTS From deleted, RQDISCUSSIONREQUIREMENTS Where deleted.ID = RQDISCUSSIONREQUIREMENTS.REQUIREMENTID
		Delete RQOVERFLOWTEXT From deleted, RQOVERFLOWTEXT Where deleted.ID = RQOVERFLOWTEXT.OVERFLOWID
		Delete RQPROJECTREQUIREMENTS From deleted, RQPROJECTREQUIREMENTS Where deleted.ID = RQPROJECTREQUIREMENTS.REQUIREMENTID
		Delete RQREQUIREMENTHISTORY From deleted, RQREQUIREMENTHISTORY Where deleted.ID = RQREQUIREMENTHISTORY.ID
		Delete RQUSERDEFINEDFIELDVALUES From deleted, RQUSERDEFINEDFIELDVALUES Where deleted.ID = RQUSERDEFINEDFIELDVALUES.REQUIREMENTID
		Delete RQUSERDEFINEDLISTVALUES From deleted, RQUSERDEFINEDLISTVALUES Where deleted.ID = RQUSERDEFINEDLISTVALUES.REQUIREMENTID
		Delete RQUSERDEFINEDRELVALUES From deleted, RQUSERDEFINEDRELVALUES Where deleted.ID = RQUSERDEFINEDRELVALUES.REQUIREMENTID
		Delete RQPACKAGEELEMENTS From deleted, RQPACKAGEELEMENTS Where deleted.ID = RQPACKAGEELEMENTS.REQUIREMENTID
	Go

	/* Trigger RQREQUIREMENTS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTS_ITRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTS_ITRIG
	Go
	Create Trigger RQREQUIREMENTS_ITRIG On RQREQUIREMENTS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTTYPES, inserted Where (RQREQUIREMENTTYPES.ID = inserted.REQUIREMENTTYPEID))
		    Begin
		        Raiserror(778007, 16, 1)
		        Rollback Transaction
		    End
	Go

	/* Trigger RQREQUIREMENTS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTS_UTRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTS_UTRIG
	Go
	Create Trigger RQREQUIREMENTS_UTRIG On RQREQUIREMENTS For Update As
		/* Prevent Updates if dependent records in 'RQDISCUSSIONREQUIREMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDISCUSSIONREQUIREMENTS Where (deleted.ID = RQDISCUSSIONREQUIREMENTS.REQUIREMENTID)) > 0
		            Begin
				Raiserror(779001, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQOVERFLOWTEXT' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQOVERFLOWTEXT Where (deleted.ID = RQOVERFLOWTEXT.OVERFLOWID)) > 0
		            Begin
				Raiserror(779007, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTREQUIREMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTREQUIREMENTS Where (deleted.ID = RQPROJECTREQUIREMENTS.REQUIREMENTID)) > 0
		            Begin
				Raiserror(779014, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTHISTORY' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTHISTORY Where (deleted.ID = RQREQUIREMENTHISTORY.ID)) > 0
		            Begin
				Raiserror(779018, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDFIELDVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDFIELDVALUES Where (deleted.ID = RQUSERDEFINEDFIELDVALUES.REQUIREMENTID)) > 0
		            Begin
				Raiserror(779024, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTVALUES Where (deleted.ID = RQUSERDEFINEDLISTVALUES.REQUIREMENTID)) > 0
		            Begin
				Raiserror(779027, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in RQUSERDEFINEDRELVALUES */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDRELVALUES Where (deleted.ID = RQUSERDEFINEDRELVALUES.REQUIREMENTID)) > 0
		            Begin
				Raiserror(779031, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in RQPACKAGEELEMENTS */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPACKAGEELEMENTS Where (deleted.ID = RQPACKAGEELEMENTS.REQUIREMENTID)) > 0
		            Begin
				Raiserror(779034, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go

/**************************************
	Table: RQREQUIREMENTTYPEFIELDS
**************************************/

	/* Trigger RQREQUIREMENTTYPEFIELDS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTTYPEFIELDS_ITRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTTYPEFIELDS_ITRIG
	Go
	Create Trigger RQREQUIREMENTTYPEFIELDS_ITRIG On RQREQUIREMENTTYPEFIELDS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTTYPES, inserted Where (RQREQUIREMENTTYPES.ID = inserted.REQUIREMENTTYPEID))
		    Begin
		        Raiserror(778007, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.USERDEFINEDFIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQREQUIREMENTTYPES
**************************************/

	/* Trigger RQREQUIREMENTTYPES_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTTYPES_DTRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTTYPES_DTRIG
	Go
	Create Trigger RQREQUIREMENTTYPES_DTRIG On RQREQUIREMENTTYPES For Delete As
		/* Prevent Deletes if dependent records in 'RQREQUIREMENTS' */
		If (Select Count(*) From deleted, RQREQUIREMENTS Where (deleted.ID = RQREQUIREMENTS.REQUIREMENTTYPEID)) > 0
		    Begin
		        Raiserror(779019, 16, 1)
		        Rollback Transaction
		    End
		Delete RQPROJECTREQUIREMENTTYPES From deleted, RQPROJECTREQUIREMENTTYPES Where deleted.ID = RQPROJECTREQUIREMENTTYPES.REQUIREMENTTYPEID
		Delete RQREQUIREMENTTYPEFIELDS From deleted, RQREQUIREMENTTYPEFIELDS Where deleted.ID = RQREQUIREMENTTYPEFIELDS.REQUIREMENTTYPEID
		Delete RQREQUIREMENTTYPESTYLES From deleted, RQREQUIREMENTTYPESTYLES Where deleted.ID = RQREQUIREMENTTYPESTYLES.REQUIREMENTTYPEID
		Delete RQREQUIREMENTTYPEUSERS From deleted, RQREQUIREMENTTYPEUSERS Where deleted.ID = RQREQUIREMENTTYPEUSERS.REQUIREMENTTYPEID
	Go

	/* Trigger RQREQUIREMENTTYPES_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTTYPES_UTRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTTYPES_UTRIG
	Go
	Create Trigger RQREQUIREMENTTYPES_UTRIG On RQREQUIREMENTTYPES For Update As
		/* Prevent Updates if dependent records in 'RQPROJECTREQUIREMENTTYPES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTREQUIREMENTTYPES Where (deleted.ID = RQPROJECTREQUIREMENTTYPES.REQUIREMENTTYPEID)) > 0
		            Begin
						Raiserror(779015, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTS Where (deleted.ID = RQREQUIREMENTS.REQUIREMENTTYPEID)) > 0
		            Begin
						Raiserror(779019, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTTYPEFIELDS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTTYPEFIELDS Where (deleted.ID = RQREQUIREMENTTYPEFIELDS.REQUIREMENTTYPEID)) > 0
		            Begin
						Raiserror(779020, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTTYPESTYLES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTTYPESTYLES Where (deleted.ID = RQREQUIREMENTTYPESTYLES.REQUIREMENTTYPEID)) > 0
		            Begin
						Raiserror(779021, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTTYPEUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTTYPEUSERS Where (deleted.ID = RQREQUIREMENTTYPEUSERS.REQUIREMENTTYPEID)) > 0
		            Begin
						Raiserror(779022, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQREQUIREMENTTYPESTYLES
**************************************/

	/* Trigger RQREQUIREMENTTYPESTYLES_ITRIG    Script Date: 10/9/98 15:13:25 ******/
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTTYPESTYLES_ITRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTTYPESTYLES_ITRIG
	Go
	Create Trigger RQREQUIREMENTTYPESTYLES_ITRIG On RQREQUIREMENTTYPESTYLES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTTYPES, inserted Where (RQREQUIREMENTTYPES.ID = inserted.REQUIREMENTTYPEID))
		    Begin
		        Raiserror(778007, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQREQUIREMENTTYPEUSERS
**************************************/

	/* Trigger RQREQUIREMENTTYPEUSERS_ITRIG    Script Date: 10/9/98 15:13:25 ******/
	If Exists (Select * From sysobjects Where name = 'RQREQUIREMENTTYPEUSERS_ITRIG' and type = 'TR')
		Drop Trigger RQREQUIREMENTTYPEUSERS_ITRIG
	Go
	Create Trigger RQREQUIREMENTTYPEUSERS_ITRIG On RQREQUIREMENTTYPEUSERS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTTYPES' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTTYPES, inserted Where (RQREQUIREMENTTYPES.ID = inserted.REQUIREMENTTYPEID))
		    Begin
		        Raiserror(778007, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERGROUPS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.USERGROUPID))
		    Begin
		        Raiserror(778011, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQUSERDEFINEDFIELDS
**************************************/

	/* Trigger RQUSERDEFINEDFIELDS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDFIELDS_DTRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDFIELDS_DTRIG
	Go
	Create Trigger RQUSERDEFINEDFIELDS_DTRIG On RQUSERDEFINEDFIELDS For Delete As
		Delete RQOVERFLOWVALUES From deleted, RQOVERFLOWVALUES Where deleted.ID = RQOVERFLOWVALUES.OVERFLOWFIELDID
		Delete RQREQUIREMENTTYPEFIELDS From deleted, RQREQUIREMENTTYPEFIELDS Where deleted.ID = RQREQUIREMENTTYPEFIELDS.USERDEFINEDFIELDID
		Delete RQUSERDEFINEDFIELDUSERS From deleted, RQUSERDEFINEDFIELDUSERS Where deleted.ID = RQUSERDEFINEDFIELDUSERS.FIELDID
		Delete RQUSERDEFINEDFIELDVALUES From deleted, RQUSERDEFINEDFIELDVALUES Where deleted.ID = RQUSERDEFINEDFIELDVALUES.FIELDID
		Delete RQUSERDEFINEDLISTITEMS From deleted, RQUSERDEFINEDLISTITEMS Where deleted.ID = RQUSERDEFINEDLISTITEMS.FIELDID
		Delete RQUSERDEFINEDLISTVALUES From deleted, RQUSERDEFINEDLISTVALUES Where deleted.ID = RQUSERDEFINEDLISTVALUES.FIELDID
		Delete RQUSERDEFINEDDOCRELVALUES From deleted, RQUSERDEFINEDDOCRELVALUES Where deleted.ID = RQUSERDEFINEDDOCRELVALUES.FIELDID
		Delete RQUSERDEFINEDRELVALUES From deleted, RQUSERDEFINEDRELVALUES Where deleted.ID = RQUSERDEFINEDRELVALUES.FIELDID
	Go

	/* Trigger RQUSERDEFINEDFIELDS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDFIELDS_UTRIG' and type = 'TR')
		Drop Trigger RQUSERDEFINEDFIELDS_UTRIG
	Go
	Create Trigger RQUSERDEFINEDFIELDS_UTRIG On RQUSERDEFINEDFIELDS For Update As
		/* Prevent Updates if dependent records in 'RQOVERFLOWVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQOVERFLOWVALUES Where (deleted.ID = RQOVERFLOWVALUES.OVERFLOWFIELDID)) > 0
		            Begin
						Raiserror(779008, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTTYPEFIELDS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTTYPEFIELDS Where (deleted.ID = RQREQUIREMENTTYPEFIELDS.USERDEFINEDFIELDID)) > 0
		            Begin
						Raiserror(779020, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDFIELDUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDFIELDUSERS Where (deleted.ID = RQUSERDEFINEDFIELDUSERS.FIELDID)) > 0
		            Begin
						Raiserror(779023, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDFIELDVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDFIELDVALUES Where (deleted.ID = RQUSERDEFINEDFIELDVALUES.FIELDID)) > 0
		            Begin
						Raiserror(779024, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTITEMS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTITEMS Where (deleted.ID = RQUSERDEFINEDLISTITEMS.FIELDID)) > 0
		            Begin
						Raiserror(779025, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTVALUES Where (deleted.ID = RQUSERDEFINEDLISTVALUES.FIELDID)) > 0
		            Begin
						Raiserror(779027, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDDOCRELVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDDOCRELVALUES Where (deleted.ID = RQUSERDEFINEDDOCRELVALUES.FIELDID)) > 0
		            Begin
						Raiserror(779030, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDRELVALUES' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDRELVALUES Where (deleted.ID = RQUSERDEFINEDRELVALUES.FIELDID)) > 0
		            Begin
						Raiserror(779031, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQUSERDEFINEDFIELDUSERS
**************************************/

	/* Trigger RQUSERDEFINEDFIELDUSERS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDFIELDUSERS_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDFIELDUSERS_ITRIG
	Go
	Create Trigger RQUSERDEFINEDFIELDUSERS_ITRIG On RQUSERDEFINEDFIELDUSERS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.FIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERGROUPS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.USERGROUPID))
		    Begin
		        Raiserror(778011, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQUSERDEFINEDFIELDVALUES
**************************************/

	/* Trigger RQUSERDEFINEDFIELDVALUES_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDFIELDVALUES_DTRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDFIELDVALUES_DTRIG
	Go
	Create Trigger RQUSERDEFINEDFIELDVALUES_DTRIG On RQUSERDEFINEDFIELDVALUES For Delete As
		Delete RQOVERFLOWVALUES From deleted, RQOVERFLOWVALUES Where deleted.REQUIREMENTID = RQOVERFLOWVALUES.OVERFLOWREQUIREMENTID AND deleted.FIELDID = RQOVERFLOWVALUES.OVERFLOWFIELDID
	Go
		
	/* Trigger RQUSERDEFINEDFIELDVALUES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDFIELDVALUES_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDFIELDVALUES_ITRIG
	Go
	Create Trigger RQUSERDEFINEDFIELDVALUES_ITRIG On RQUSERDEFINEDFIELDVALUES For Insert, Update As
		/* Prevent Updates if dependent records in 'RQOVERFLOWVALUES' */
		If Update(FIELDID)
		    Begin
		        If (Select Count(*) From deleted, RQOVERFLOWVALUES Where (deleted.FIELDID = RQOVERFLOWVALUES.OVERFLOWFIELDID)) > 0
		            Begin
						Raiserror(779008, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.REQUIREMENTID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.FIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQUSERDEFINEDLISTITEMS
**************************************/

	/* Trigger RQUSERDEFINEDLISTITEMS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDLISTITEMS_DTRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDLISTITEMS_DTRIG
	Go
	Create Trigger RQUSERDEFINEDLISTITEMS_DTRIG On RQUSERDEFINEDLISTITEMS For Delete As
		Delete RQUSERDEFINEDLISTITEMUSERS From deleted, RQUSERDEFINEDLISTITEMUSERS Where deleted.ITEMID = RQUSERDEFINEDLISTITEMUSERS.LISTITEMID
		Delete RQUSERDEFINEDLISTVALUES From deleted, RQUSERDEFINEDLISTVALUES Where deleted.ITEMID = RQUSERDEFINEDLISTVALUES.LISTITEMID
	Go

	/* Trigger RQUSERDEFINEDLISTITEMS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDLISTITEMS_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDLISTITEMS_ITRIG
	Go
	Create Trigger RQUSERDEFINEDLISTITEMS_ITRIG On RQUSERDEFINEDLISTITEMS For Insert, Update As
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTITEMUSERS' */
		If Update(ITEMID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTITEMUSERS Where (deleted.ITEMID = RQUSERDEFINEDLISTITEMUSERS.LISTITEMID)) > 0
		            Begin
						Raiserror(779026, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTVALUES' */
		If Update(ITEMID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTVALUES Where (deleted.ITEMID = RQUSERDEFINEDLISTVALUES.LISTITEMID)) > 0
		            Begin
						Raiserror(779027, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Validation rule for field 'ITEMRANK' */
		If (Select Count(*) From inserted Where NOT (ITEMRANK>=0)) > 0
		    Begin
		        Raiserror(777000, 16, 1)
		        Rollback Transaction
		    End 
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.FIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQUSERDEFINEDLISTITEMUSERS
**************************************/

	/* Trigger RQUSERDEFINEDLISTITEMUSE_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDLISTITEMUSE_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDLISTITEMUSE_ITRIG
	Go
	Create Trigger RQUSERDEFINEDLISTITEMUSE_ITRIG On RQUSERDEFINEDLISTITEMUSERS For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQPROJECTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQPROJECTS, inserted Where (RQPROJECTS.ID = inserted.PROJECTID))
		    Begin
		        Raiserror(778004, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDLISTITEMS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDLISTITEMS, inserted Where (RQUSERDEFINEDLISTITEMS.ITEMID = inserted.LISTITEMID))
		    Begin
		        Raiserror(778010, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERGROUPS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.USERGROUPID))
		    Begin
		        Raiserror(778011, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQUSERDEFINEDLISTVALUES
**************************************/

	/* Trigger RQUSERDEFINEDLISTVALUES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDLISTVALUES_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDLISTVALUES_ITRIG
	Go
	Create Trigger RQUSERDEFINEDLISTVALUES_ITRIG On RQUSERDEFINEDLISTVALUES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.REQUIREMENTID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.FIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDLISTITEMS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDLISTITEMS, inserted Where (RQUSERDEFINEDLISTITEMS.ITEMID = inserted.LISTITEMID))
		    Begin
		        Raiserror(778010, 16, 1)
		        Rollback Transaction
		    End
	Go


/************************************************
	Table: RQUSERDEFINEDDOCRELVALUES
************************************************/

	/* Trigger RQUSERDEFINEDDOCRELVALUES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDDOCRELVALUES_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDDOCRELVALUES_ITRIG
	Go
	Create Trigger RQUSERDEFINEDDOCRELVALUES_ITRIG On RQUSERDEFINEDDOCRELVALUES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQDOCUMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQDOCUMENTS, inserted Where (RQDOCUMENTS.ID = inserted.DOCUMENTID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.FIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
	Go


/************************************************
	Table: RQUSERDEFINEDRELVALUES
************************************************/

	/* Trigger RQUSERDEFINEDRELVALUES_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERDEFINEDRELVALUES_ITRIG' and type = 'TR')
		drop Trigger RQUSERDEFINEDRELVALUES_ITRIG
	Go
	Create Trigger RQUSERDEFINEDRELVALUES_ITRIG On RQUSERDEFINEDRELVALUES For Insert, Update As
		/* Prevent Inserts/Updates if no matching key in 'RQREQUIREMENTS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQREQUIREMENTS, inserted Where (RQREQUIREMENTS.ID = inserted.REQUIREMENTID))
		    Begin
		        Raiserror(778006, 16, 1)
		        Rollback Transaction
		    End
		/* Prevent Inserts/Updates if no matching key in 'RQUSERDEFINEDFIELDS' */
		If (Select Count(*) From inserted) != (Select Count(*) From RQUSERDEFINEDFIELDS, inserted Where (RQUSERDEFINEDFIELDS.ID = inserted.FIELDID))
		    Begin
		        Raiserror(778008, 16, 1)
		        Rollback Transaction
		    End
	Go


/**************************************
	Table: RQUSERGROUPS
**************************************/

	/* Trigger RQUSERGROUPS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERGROUPS_DTRIG' and type = 'TR')
		drop Trigger RQUSERGROUPS_DTRIG
	Go
	Create Trigger RQUSERGROUPS_DTRIG On RQUSERGROUPS For Delete As
		/* Prevent Deletes if dependent records in 'RQUSERS' */
		If (Select Count(*) From deleted, RQUSERS Where (deleted.ID = RQUSERS.GROUPID)) > 0
		    Begin
		        Raiserror(779028, 16, 1)
		        Rollback Transaction
		    End
		Delete RQDISCUSSIONGROUPS From deleted, RQDISCUSSIONGROUPS Where deleted.ID = RQDISCUSSIONGROUPS.GROUPID
		Delete RQDOCUMENTTYPEUSERS From deleted, RQDOCUMENTTYPEUSERS Where deleted.ID = RQDOCUMENTTYPEUSERS.USERGROUPID
		Delete RQPROJECTUSERS From deleted, RQPROJECTUSERS Where deleted.ID = RQPROJECTUSERS.USERGROUPID
		Delete RQREQUIREMENTTYPEUSERS From deleted, RQREQUIREMENTTYPEUSERS Where deleted.ID = RQREQUIREMENTTYPEUSERS.USERGROUPID
		Delete RQUSERDEFINEDFIELDUSERS From deleted, RQUSERDEFINEDFIELDUSERS Where deleted.ID = RQUSERDEFINEDFIELDUSERS.USERGROUPID
		Delete RQUSERDEFINEDLISTITEMUSERS From deleted, RQUSERDEFINEDLISTITEMUSERS Where deleted.ID = RQUSERDEFINEDLISTITEMUSERS.USERGROUPID
	Go

	/* Trigger RQUSERGROUPS_UTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERGROUPS_UTRIG' and type = 'TR')
		Drop Trigger RQUSERGROUPS_UTRIG
	Go
	Create Trigger RQUSERGROUPS_UTRIG On RQUSERGROUPS For Update As
		/* Prevent Updates if dependent records in 'RQDISCUSSIONGROUPS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDISCUSSIONGROUPS Where (deleted.ID = RQDISCUSSIONGROUPS.GROUPID)) > 0
		            Begin
						Raiserror(779000, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQDOCUMENTTYPEUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQDOCUMENTTYPEUSERS Where (deleted.ID = RQDOCUMENTTYPEUSERS.USERGROUPID)) > 0
		            Begin
						Raiserror(779006, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQPROJECTUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQPROJECTUSERS Where (deleted.ID = RQPROJECTUSERS.USERGROUPID)) > 0
		            Begin
						Raiserror(779016, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQREQUIREMENTTYPEUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQREQUIREMENTTYPEUSERS Where (deleted.ID = RQREQUIREMENTTYPEUSERS.USERGROUPID)) > 0
		            Begin
						Raiserror(779022, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDFIELDUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDFIELDUSERS Where (deleted.ID = RQUSERDEFINEDFIELDUSERS.USERGROUPID)) > 0
		            Begin
						Raiserror(779023, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERDEFINEDLISTITEMUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERDEFINEDLISTITEMUSERS Where (deleted.ID = RQUSERDEFINEDLISTITEMUSERS.USERGROUPID)) > 0
		            Begin
						Raiserror(779026, 16, 1)
		                Rollback Transaction
		            End
		    End
		/* Prevent Updates if dependent records in 'RQUSERS' */
		If Update(ID)
		    Begin
		        If (Select Count(*) From deleted, RQUSERS Where (deleted.ID = RQUSERS.ID)) > 0
		            Begin
						Raiserror(779028, 16, 1)
		                Rollback Transaction
		            End
		    End
	Go


/**************************************
	Table: RQUSERS
**************************************/

	/* Trigger RQUSERS_DTRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERS_DTRIG' and type = 'TR')
		drop Trigger RQUSERS_DTRIG
	Go
	Create Trigger RQUSERS_DTRIG On RQUSERS For Delete As
		Delete RQDISCUSSIONSREAD From deleted, RQDISCUSSIONSREAD Where deleted.ID = RQDISCUSSIONSREAD.USERID
		Delete RQDISCUSSIONUSERS From deleted, RQDISCUSSIONUSERS Where deleted.ID = RQDISCUSSIONUSERS.USERID
	Go

	/* Trigger RQUSERS_ITRIG */
	If Exists (Select * From sysobjects Where name = 'RQUSERS_ITRIG' and type = 'TR')
		drop Trigger RQUSERS_ITRIG
	Go
	Create Trigger RQUSERS_ITRIG On RQUSERS For Insert, Update As
	/* Prevent Updates if dependent records in 'RQDISCUSSIONSREAD' */
	If Update(ID)
	    Begin
	        If (Select Count(*) From deleted, RQDISCUSSIONSREAD Where (deleted.ID = RQDISCUSSIONSREAD.USERID)) > 0
	            Begin
					Raiserror(779002, 16, 1)
	                Rollback Transaction
	            End
	    End
	/* Prevent Updates if dependent records in 'RQDISCUSSIONUSERS' */
	If Update(ID)
	    Begin
	        If (Select Count(*) From deleted, RQDISCUSSIONUSERS Where (deleted.ID = RQDISCUSSIONUSERS.USERID)) > 0
	            Begin
					Raiserror(779003, 16, 1)
	                Rollback Transaction
	            End
	    End
	/* Prevent Inserts/Updates if no matching key in 'RQUSERGROUPS' */
	If (Select Count(*) From inserted) != (Select Count(*) From RQUSERGROUPS, inserted Where (RQUSERGROUPS.ID = inserted.GROUPID))
	    Begin
	        Raiserror(778011, 16, 1)
	        Rollback Transaction
	    End
	Go

/**************************************
    Stored Procedure: RQDROP_VIEW
**************************************/

if exists (select * from sysobjects where name = 'RQDROP_VIEW' and type = 'P')
	drop procedure RQDROP_VIEW
GO

CREATE PROCEDURE RQDROP_VIEW (@id integer) AS

DECLARE
  @sql_txt1 varchar(50),
  @sql_txt2 varchar(50),
  @sortView varchar(50),
  @attrView varchar(50),
  @msg varchar(100),
  @charId varchar(10)
BEGIN
  SET NOCOUNT ON
  SELECT @charId = CONVERT(varchar(10), @id)
  SELECT @attrView = 'RQATTRVALUESVIEW_' + @charId
  SELECT @sql_txt1 = 'DROP VIEW ' + @attrView
  SELECT @sortView = 'RQATTRVALUESSORTVIEW_' + @charId
  SELECT @sql_txt2 = 'DROP VIEW ' + @sortView
  EXECUTE (@sql_txt1)
  if (@@error <> 0) and (@@error <> 3701)
    BEGIN
      SELECT @msg = 'Unable to drop view ' + @attrView + '.'
      PRINT @msg
    END
  If Exists (Select * From sysobjects Where name = @sortView and type = 'V')
    BEGIN
      EXECUTE (@sql_txt2)
      if (@@error <> 0) and (@@error <> 3701)
        BEGIN
          SELECT @msg = 'Unable to drop view ' + @sortView + '.'
          PRINT @msg
        END
    END
END

GO

/**************************************
    Stored Procedure: RQDROP_VIEWS
**************************************/

if exists (select * from sysobjects where name = 'RQDROP_VIEWS' and type = 'P')
	drop procedure RQDROP_VIEWS
GO

CREATE PROCEDURE RQDROP_VIEWS (@projId integer) AS

DECLARE 
  @attrId integer
DECLARE c1 CURSOR FOR
    SELECT RTF.USERDEFINEDFIELDID
    FROM RQREQUIREMENTTYPEFIELDS RTF,
         RQPROJECTREQUIREMENTTYPES PRT
    WHERE RTF.REQUIREMENTTYPEID = PRT.REQUIREMENTTYPEID
    AND PRT.PROJECTID = @projId
BEGIN
  OPEN c1
  FETCH NEXT FROM c1 INTO @attrId
  WHILE (@@FETCH_STATUS = 0)
  BEGIN
    EXECUTE RQDROP_VIEW @attrId
    FETCH NEXT FROM c1 INTO @attrId
  END
CLOSE c1
END
GO

/**************************************
  Stored Procedure: RQDELETE_PROJECT
**************************************/


	If Exists (SELECT * FROM sysobjects WHERE name = 'RQDELETE_PROJECT' AND type = 'P')
		Drop Procedure RQDELETE_PROJECT
	GO

	CREATE PROCEDURE RQDELETE_PROJECT (@projId integer) AS

	DECLARE @msg varchar(100)

	SET NOCOUNT ON

	If Not Exists(SELECT * FROM RQPROJECTS WHERE ID=@projId) 
		BEGIN
			SELECT @msg = 'Project ' + CONVERT(varchar(10), @projId) + ' does not exist. Project was not deleted.'
			PRINT @msg
			RETURN
		END

	EXECUTE RQDROP_VIEWS @projId

	BEGIN TRANSACTION

		DELETE FROM RQDOCUMENTTYPEUSERS WHERE PROJECTID = @projId
		if (@@error <> 0)
			goto errorFound

		DELETE FROM RQREQUIREMENTTYPEUSERS WHERE PROJECTID = @projId
		if (@@error <> 0)
			goto errorFound

		DELETE FROM RQUSERDEFINEDFIELDUSERS WHERE PROJECTID = @projId
		if (@@error <> 0)
			goto errorFound

		DELETE FROM RQUSERDEFINEDLISTITEMUSERS WHERE PROJECTID = @projId
		if (@@error <> 0)
			goto errorFound

		DELETE FROM RQUSERS WHERE GROUPID IN
			(SELECT USERGROUPID FROM RQPROJECTUSERS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE FROM RQUSERGROUPS WHERE ID IN 
			(SELECT USERGROUPID FROM RQPROJECTUSERS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQDISCUSSIONS WHERE ROOTID IN 
			(SELECT DISCUSSIONID FROM RQPROJECTDISCUSSIONS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQOVERFLOWHISTORY WHERE OVERFLOWTYPE = 2 AND OVERFLOWID IN
			(SELECT DOCUMENTID FROM RQPROJECTDOCUMENTS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQDOCUMENTS WHERE ID IN 
			(SELECT DOCUMENTID FROM RQPROJECTDOCUMENTS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQDOCUMENTTYPES WHERE ID IN 
			(SELECT DOCUMENTTYPEID FROM RQPROJECTDOCUMENTTYPES WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQTORELATIONSHIPS WHERE EXTERNALPROJECTID = 0 AND REQUIREMENTID IN
			(SELECT REQUIREMENTID FROM RQPROJECTREQUIREMENTS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQTORELATIONSHIPS WHERE EXTERNALPROJECTTOID = 0 AND TOID IN
			(SELECT REQUIREMENTID FROM RQPROJECTREQUIREMENTS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQOVERFLOWHISTORY WHERE OVERFLOWTYPE = 1 AND OVERFLOWID IN
			(SELECT REQUIREMENTID FROM RQPROJECTREQUIREMENTS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQREQUIREMENTS WHERE ID IN 
			(SELECT REQUIREMENTID FROM RQPROJECTREQUIREMENTS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQUSERDEFINEDFIELDS WHERE ID IN
			(SELECT USERDEFINEDFIELDID FROM RQREQUIREMENTTYPEFIELDS F, RQPROJECTREQUIREMENTTYPES P
			 WHERE F.REQUIREMENTTYPEID = P.REQUIREMENTTYPEID AND PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQREQUIREMENTTYPES WHERE ID IN
			(SELECT REQUIREMENTTYPEID FROM RQPROJECTREQUIREMENTTYPES WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQQUERYDEFINITIONS WHERE ID IN
			(SELECT SECONDARYQUERYID FROM RQVIEWS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound

		DELETE RQQUERYDEFINITIONS WHERE ID IN
			(SELECT QUERYID FROM RQVIEWS WHERE PROJECTID = @projId)
		if (@@error <> 0)
			goto errorFound
  
		DELETE RQOVERFLOWHISTORY WHERE OVERFLOWTYPE = 3 AND OVERFLOWID = @projId
		if (@@error <> 0)
			goto errorFound
 
		DELETE FROM RQEXTERNALPROJECTS WHERE ID = @projId
		if (@@error <> 0)
			goto errorFound

		Alter Table RQPROJECTS Disable Trigger RQPROJECTS_DTRIG_BLOCK
		Alter Table RQPROJECTS Enable Trigger RQPROJECTS_DTRIG

		DELETE FROM RQPROJECTS WHERE ID = @projId
		if (@@error <> 0)
			goto errorFound

		Alter Table RQPROJECTS Disable Trigger RQPROJECTS_DTRIG
		Alter Table RQPROJECTS Enable Trigger RQPROJECTS_DTRIG_BLOCK

	COMMIT TRANSACTION

	BEGIN TRANSACTION

		DELETE FROM RQEXTERNALPROJECTS WHERE ID NOT IN
			(SELECT EXTERNALPROJECTID FROM RQPROJECTEXTERNALPROJECTS)
		if (@@error <> 0)
			goto errorFound

	COMMIT TRANSACTION

	SELECT @msg = 'Project ' + CONVERT(varchar(10), @projId) + ' was successfully deleted.'
	PRINT @msg
	RETURN

errorFound:
	ROLLBACK TRANSACTION
	SELECT @msg = 'Error occurred while deleting project ' + CONVERT(varchar(10), @projId) + '. Project was not deleted.'
	PRINT @msg
GO

Setuser
